@@ -18,50 +18,19 @@ they publish the methods for GET, POST, PUT and DELETE. They are obviously
 part of packages in this instance, but they *should* be refactored to make wholesome
 sense in the api they publish.
 """
-import sys, os
-
-import plugins.template
-import plugins.dblayer
-import utils
-import dispatcher
 import settings
 import _urls
-import app
 
 
 __all__ = [
 		'urladd', 
-		'start',
 		'run'
 		]
 
 urladd = _urls.urladd
 
-
-
-
-def start(config, method):
-	#TODO: think of how to make it such that we only get the function we want from 
-	# the method plugins
-	import plugins.runmethods
-	runmethod = getattr(plugins.runmethods, method)
-	runmethod(config)
-
 def run(method='development'):
+	import plugins.runmethods
 	config = settings.Config("config")
-	#TODO: make this use pkg_resources later
-	config.dirname = os.path.dirname(config.__file__)
-
-	if not hasattr(config, 'port') or str(getattr(config, 'port')).strip() == '' or getattr(config, 'port') is None:
-		config.port = 8080
-
-	if not hasattr(config, 'host'):
-		config.host = '127.0.0.1'
-
-	if not hasattr(config, 'enable_debug'):
-		config.enable_debug = False
-
-	if not hasattr(config, 'enable_sessions'):
-		config.enable_sessions = False
-
-	start(config, method)
+	runmethods = getattr(plugins.runmethods, method)
+	runmethods(_urls, config)
