@@ -9,7 +9,7 @@ in the internal development web server
 	"""
 
 	if len(args) > 0:
-		sys.stderr.write("RUN takes no arguments\n")
+		simpleweb.utils.msg_err("RUN takes no arguments")
 		sys.exit(0)
 
 	simpleweb.run()
