@@ -1,6 +1,6 @@
 import sys
-from flup.middleware.session import DiskSessionStore, SessionMiddleware
-from middleware import StaticMiddleware, AuthMiddleware
+from middleware import StaticMiddleware, AuthMiddleware, SimpleErrorMiddleware 
+import simpleweb.utils
 
 class SimplewebApp(object):
 	def __init__(self, urls, config):
@@ -18,6 +18,7 @@ class SimplewebReloadingApp(object):
 		config = simpleweb.settings.Config("config")
 
 		wsgiapp = _create_app(urls, config)
+		wsgiapp = SimpleErrorMiddleware(wsgiapp, config.enable_debug, msg="An error has occured.\nFor a detailed traceback, enable debugging in config.py.\n You can do this by setting <pre >enable_debug = True</pre>")
 		return wsgiapp(environ, start_response)
 		
 
@@ -26,7 +27,8 @@ def _create_app(url, config):
 		sys.path.insert(0, '.')
 		__import__('urls')
 	except ImportError, e:
-		sys.stderr.write("Could not successfully import urls.py. Details follow:\n\t%s\n" % (e))
+		simpleweb.utils.msg_err("Could not successfully import urls.py: %s" % (e))
+		sys.exit()
 
 	app = url.geturls()
 
@@ -37,6 +39,10 @@ def _create_app(url, config):
 		app = AuthMiddleware(app, authuser_class=config.auth_plugin.authuser_class)
 	#TODO: add config attributes to control session initialization (e.g config.session_timeout)
 	if config.enable_sessions:
-		app = SessionMiddleware(DiskSessionStore(), app)
-
+		try:
+			from flup.middleware.session import DiskSessionStore, SessionMiddleware
+			app = SessionMiddleware(DiskSessionStore(), app)
+		except ImportError:
+			pass
+	
 	return app
